#
# spec file for package goverlay
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           goverlay
Version:        1.2
Release:        1.3
Summary:        Graphical UI to help manage overlays
License:        GPL-3.0-or-later
URL:            https://github.com/benjamimgois/goverlay
Source0:        https://github.com/benjamimgois/goverlay/archive/refs/tags/%{version}.tar.gz#/%{name}-%{version}.tar.gz
# PATCH-FIX-OPENSUSE goverlay-enable-debuginfo-generation.patch andythe_great@pm.me -- Enable generate debuginfo
Patch0:         goverlay-enable-debuginfo-generation.patch
BuildRequires:  appstream-glib
BuildRequires:  desktop-file-utils
BuildRequires:  lazarus
BuildRequires:  libQt6Pas-devel
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(gtk+-3.0)
ExclusiveArch:  x86_64 aarch64
Requires:       mangohud
Recommends:     Mesa-demo
Recommends:     vkbasalt
Recommends:     vulkan-tools
%if 0%{?suse_version} > 1500
BuildRequires:  lazarus-lcl-qt6
%endif

%description
GOverlay is a graphical UI to manage Vulkan/OpenGL overlays.

%prep
%autosetup -p1
chmod -x LICENSE README.md

%build
%{set_build_flags}
%make_build

%install
%make_install prefix=%{_prefix} libexecdir=/%{_lib}
%suse_update_desktop_file -r io.github.benjamimgois.%{name} Development Profiling
%{__strip} %{buildroot}/usr/lib64/goverlay

%check
appstream-util validate-relax --nonet %{buildroot}%{_datadir}/metainfo/*.xml
desktop-file-validate %{buildroot}%{_datadir}/applications/io.github.benjamimgois.%{name}.desktop

%files
%license LICENSE
%doc README.md
%{_bindir}/%{name}
%{_libdir}/%{name}
%{_datadir}/applications/*.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}.png
%{_mandir}/man1/%{name}.1%{?ext_man}
%{_datadir}/metainfo/io.github.benjamimgois.%{name}.metainfo.xml

%changelog
* Tue Jul 30 2024 pallas wept <pallaswept@proton.me>
- Update to version 1.2:
  New:
  * Presets (formerly known as quick layouts) are back.
  * Custom user presets can now be saved and restored (requested feature).
  * Added negative offset option for FPS limits, very useful for VRR screens
    (requested feature).
  * New FPS AVG 1%% and 0.1%% options.
  * New winesync option.
  * New compact HUD option.
  * New Vulkan Present mode option.
  * Added Fahrenheit temperature unit option (requested feature).
  * Option to disable shortcut combinations (requested feature).
  * Icons for device battery.
  Fixes:
  * Fixed missing arguments for device battery.
  * GPU and CPU custom colors are working again.
  * Time toggle was always checked, now fixed.
  * Fixed invalid string used for engine_version.-
- Use Qt6Pas for build
* Sat Jun  1 2024 jonatas.sgoncalves@gmail.com
- Update to version 1.1.1:
  * update version to 1.10
  * update qt6pas url
  * FIX: Update dependencies definition to QT6
  * Update README.md
  * Update README.md
  * Update app logo and centralize main app window
  * Disable AF and Mipmap if value is 0
  * Update io.github.benjamimgois.goverlay.desktop
  * Add files via upload
  * Add files via upload
  * Add files via upload
* Thu Feb 22 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Do not use %%attr(644,-,-) %%license: this happens to also create
  the relevant directories with mode 644, i.e not accessible.
  Rather remove the spurious exec bits from the files during prep.
* Mon Jan  8 2024 Antonio Teixeira <antonio.teixeira@suse.com>
- Update to 1.0:
  * A much speedier, shiny new codebase
  * Now compatible with Wayland
  * Every *.TTF font in /usr/share/fonts is ready to use
  * A fresh look for the user interface
  * Loads of new features inspired by MangoHUD 0.7
  * Bid farewell to replaysorcery
- Change Mesa-demo, vkbasalt and vulkan-tools to weak dependencies.
- Remove replay-sorcery dependency.
* Sun Oct  1 2023 munix9@googlemail.com
- Fix build on Factory/TW: requires lazarus-lcl-qt5.
- Clean up spec file.
* Thu Dec 22 2022 Dirk Müller <dmueller@suse.com>
- update to 0.9.1:
  * NEW: Mangohud - Multigpu support with PCIDEV option
  * NEW: Mangohud - Vertical and horizontal hud orientation (not in the
    mangohud stable yet, you need use mangohud-git for it)
  * NEW: Mangohud - NVME temperature option
  * New: Goverlay - Transparency trackbar moved to main form
  * New: Goverlay - Opengl Cube has a widemode to better fit the hud
    horizontal orientation
  * FIX: Goverlay - Interface fonts adjustments to improve interface
    scalling
  * Fix: Tabs reorder (Visual is the first one now)
  * FIX: removed message ¨paint" spammed when running from terminal
  * Change: Some cosmetic changes on the spinning cube
  * Change: Removed framecount from the "Complete" quick layout
  * Fix: Removed lsb_release dependency and reimplemented feature through
    os-release file. by @GloriousEggroll
  * Removed: Hack option to run steam with deckUI (no longer needed)
* Sun Mar 13 2022 Simon Vogl <simon.vogl@gmx.net>
- Update to version 0.9.
  * NEW: Mangohud - Added frame_count option to display the number
    of frames since start
  * NEW: Mangohud - Added GPU throttling option to show if GPU is
    throttling based on Power, current, temp or "other" (Only shows
    if throttling is currently happening)
  * NEW: Mangohud - Selected quick layout button will keep the
    active color
  * NEW: Mangohud - Added Option to run vkcube with Gamescope in
    the Hamburguer menu
  * FIX: Removed Breeze theme dependency/style. GUI will use the
    current system theme but it is optimised for Breeze (QT) and
    Adwaita (GTK) themes.
  * FIX: Mangohud - Driverversion wasn't selected on the complete
    quick layout
  * FIX: Mangohud - Displayed Kernelversion will update
    automatically now (not attached to a text file anymore)
  * FIX: Mangohud - Notifications didn't expire, now they are
    transient (thanks @NoXPhasma)
  * FIX: VKbasalt - Changed menu icon to standart hamburguer menu
  * FIX: Vkbasalt , replaysorcery - Display wrong hint message from
    the mangohud toolbox
* Sun Mar 13 2022 Simon Vogl <simon.vogl@gmx.net>
- Update to version 0.8 & 0.8.1.
  * NEW - New option to start steam using the Deck UI
  * NEW - New Classic mode to fix the problem of white text in
    white background for GTK desktops with no Breeze theme.
    Issue #198
  * FIX - Created icons for hamburguer options.
  * FIX - Re-add Autostart logging feature. Issue #188
  * FIX - Wrong hint on log duration. Issue #188
  * NEW: Mangohud - Display gamepad controllers battery status
    (needs xone driver for xbox one and series X controllers)
  * NEW: Mangohud - Preconfigure color themes (Mangohud default,
    Simple White, Old Afterburner, Intel + Nvidia, Intel + Radeon,
    AMD + Nvidia, AMD + Radeon)
  * NEW: Mangohud - Added option FPS_Only to display only FPS value.
    Issue #192
  * NEW: Mangohud - Added Minimal quick layout with only fps and
    frametime
  * FIX: Global enable method updated. Issue #186
  * FIX: Mangohud - Colors from colorsbuttons resemble but doesn't
    matched the stock mangohud. Now they do.
  * FIX: Removed the lines "exec=echo" from baterry config. It seems
    it were causing steam errors. Issue #178
  * FIX: Custom FPS field was locked to 200. Now the maximum value
    is 999. Issue #172
  * FIX: Added Dependency checker for Breeze-theme
  * CHANGE: Changed cpuload color 2 to a lighter orange tone: old
    $000078FF , new $007FAAFF
  * CHANGE: Preconfigure layouts now instantly save the new options
    and update previews
  * CHANGE: Now a “Config saved” message is also displayed next to
    the save button. It disapear on mouse enter the mangohud panel.
* Fri Dec 17 2021 andy great <andythe_great@pm.me>
- Update to version 0.7.1.
  * NEW: Goverlay: Switch QT theme from Fusion to Breeze
  * NEW: Goverlay: Change panel backgrounds from color "cldefault"
    to dark gray "$00383838"
  * FIX: Goverlay: Several aligments ajustments due to diferences
    in controls sizes
  * FIX: Goverlay: Save buttons using Noto-sans font instead Sans
    font
  * FIX: Goverlay: Save buttons font color changed from "cldefault"
    to "clwhite". (Fix a problem with adwaita theme)
  * FIX: Goverlay: Bitbtns changed from Darkgray "$00383838"
    background to "cldefault" (Fix a problem with adwaita theme)
  * FIX: ReplaySorcery: Repositioned the "Full screen" and "Auto"
    options to fit Breeze
* Tue Nov 30 2021 andy great <andythe_great@pm.me>
- Update to version 0.7.
  * NEW: Goverlay - tabbed UI optimized for steamdeck resolution.
    (1280x800)
  * NEW: Mangohud - Added hud positions middle-left and middle-right
  * NEW: Mangohud - Added round corners option to hud background
  * Many fixes around the code
* Sun Oct 31 2021 andy great <andythe_great@pm.me>
- Update to version 0.6.4.
  * NEW / FIX: New global-enable implementation.
    (Needs to enter 2x the root password)
  * NEW / FIX: Force x11 mode by default, so goverlay works on
    wayland enviroments
  * New: Mangohud - Added option to choose diferent font types
    (DejavuSans, DejavuSans Bold, DejavuSans Oblique, DejavuSans
    Bold Oblique, DejavuSans Light, Ubuntu regular, Ubuntu Bold,
    Ubuntu Medium).
  * New: Mangohud - Added option to monitor Process Memory usage
  * FIX: Mangohud - Swap option was checked when you select the
    GRAPHs prebuilt option.
  * FIX: ReplaySorcery - Fixed typo in the configuration file
    (videoBitratey instead videoBitrate).
* Mon Sep 13 2021 andy great <andythe_great@pm.me>
- Update to version 0.6.3.
  * NEW: Add vkcube test inside the Gamemenu button
  * NEW: Add script "start_goverlay.sh" to the .tar.xz binary
  * FIX: Fixed the custom FPS option that broke some updates ago.
  * FIX: Changed Distro version implementation so it works on steam
    games now.
  * FIX: Code cleanup after text hud was removed
  * FIX: small interface fixes
* Sat Aug 21 2021 andy great <andythe_great@pm.me>
- Update to version 0.6.2.
  * NEW: Implemented realtime Opengl cube for realtime hud preview.
  * NEW: Keybind to upload logging results to flightlessmango.com
  * FIX: Save button on the logging folder window automatically
    closes the form. (Asked by jason)
  * FIX: VKbasalt generating wrong path for Shaders folder
  * FIX: Small interface tweaks
  * REMOVE: Text hud preview
* Thu Jul 29 2021 andy great <andythe_great@pm.me>
- Update to version 0.6.1.
  * fix: Distro info , Session and /home texts weren't displaying
    correctly (Thanks to @devnull for the help)
  * fix: HUD Title text doesn't apear as intended
  * fix: Hints for Hud title and Custom command text boxes doesn't
    apear.
* Thu Jul 22 2021 andy great <andythe_great@pm.me>
- Update to version 0.6.0.
  * New: Mangohud - Included core_load_change in load_change CPU
    option
  * New: Mangohud - include Gamemode status
  * New: Mangohud - include vkbasalt status
  * New: Mangohud - include max fps limit
  * New: Mangohud - include Session Type (x11 or wayland)
  * New: Mangohud - include Current resolution
  * New: Mangohud - include battery status
  * New: Mangohud - include Distribution info
    (Distro name, version and kernel)
  * New: Mangohud - Added new fps limits
    (60 / 30 , 120 / 60, 240 , 360, 420)
  * New: vkbasalt - Added option to launch steam, lutris or heroic
    with vkbasalt enabled
  * fix: vkbasalt - Removed glxgears from vkbasalt test button
  * New: ReplaySorcery - Added new video encoders from 0.6 release
    (x265, hevc, vaapi_h264, vaapi_hevc)
  * fix: Tweaks in Global enablement for Mangohud and vkbasalt
  * fix: fix showing red dot when MangoHud is the only missing
    dependency
* Sat Jun  5 2021 andy great <andythe_great@pm.me>
- Update to version 0.5.1.
  * New: Mangohud - Redesigned GRAPHs layout to better suit
    different distribution QT themes. (WIP)
  * New: Mangohud - Added missing SWAP option
  * New: Mangohud - Added option to force run Gamelaunchers
    (Steam, Lutris and Heroic) with Mangohud, this can fix problems
    with opengl games not showing mangohud correctly and some
    distros not working properly with the global enablement.
  * Support running previews without mangohud
  * Replace "Find" with "Which" command for better distro compatibility
  * Fixed notification typos
- Updates for 0.5.0.
  * New: Mangohud - Added option to display GRAPHs on Mangohud
  * New: Mangohud - Added new Hud Type (GRAPH HUD)
  * New: Mangohud - Added Fix to display power Drawn on intel CPUs
  * New: Mangohud - Added option to display or hide the FPS counter
  * New: Mangohud - Moved HUD version and Time options to the
    botton part of the HUD
  * Fix: GUI - small fixes in the interfaces.
  * Fix: VKbasalt - Wrong color used on Toggle key combobox
  * Fix: About - Wrong colors on about page
* Thu Feb  4 2021 andy great <andythe_great@pm.me>
- Update to version 0.4.4.
  * Support for ReplaySorcery 0.5.0.
- Updates for 0.4.3.
  * New functions introduced in mangohud 0.6.1 and some fixes to
    vkbasalt implementation and Replaysorcery
  * New - Added option to change CPU and GPU colors based on Load
    introduced in MangoHUD 0.6.1
  * New - Added option to autostart logging after specific seconds
    introduced in MangoHUD 0.6.1
  * New - Added option to display CPU Power introduced in MangoHUD
    0.6.1
  * New - Added option to display CPU Frequency introduced in
    MangoHUD 0.6.1
  * Fix - Interface overhaul in replaysorcery
  * Fix - Mangohud lost configuration after saving a config for
    replaysorcery
  * Fix - CAS doesn't work in VKbasalt if other effects weren't in
    use
  * Fix - Comboboxes with wrong font sizes
  * Fix - Hudversion remove from compact and complete hud profile
  * Fix - Time removed from complete hud profile
  * Fix - trackbars of CAS in vkbasalt and Compress quality in
    replaySorcery do not display values on QT5
  * Fix - Small interface changes
* Wed Jan  6 2021 andy great <andythe_great@pm.me>
- Add replay-sorcery as dependency.
* Sun Nov 29 2020 andy great <andythe_great@pm.me>
- Update to version 0.4.2.
  * Fix - Application building now defaults to QT5
  * Fix - ReplaySorcery consistent naming
  * Fix - Use cmdline arg instead of env var for qt style in
    .desktop file
  * Fix - removes the local session files from git
  * Fix - Update metainfo screenshots
- Updates for 0.4.1.
  * New - Migration from GTK2 to QT5 toolkit with Fusion QT Style
  * New - Added precustom compact Hud option in mangohud
  * New - Added option to customize colors of Engine, Wine and
    Media in mangohud
  * Fix - Theme ajustments for QT5 integration
  * Fix - Some items weren't correctly colored on the preview
    interface in mangohud
  * Fix - Minor typos in ReplaySorcery
  * Fix - HIDPI displays works correctly with goverlay in QT5
- Fix spec file to use Makefile.
* Wed Nov  4 2020 andy great <andythe_great@pm.me>
- Update to version 0.4.
  * New - Added full replay-sourcery implementation
  * New - created hint messages for each application
  * New - Toggle keys refactored to F1 - F4
    (stock values mantained)
  * Fix - vkbasalt wasn't correctly activated when running the
    test button
  * Fix - vkbasalt doesn't save toggle button option
  * Fix - vkbasalt doesn't save CAS option when in false state
  * Fix - Dependency error message doesn't fit screen space
  * Fix - font colors doesn't fit light themes in some ocasions
* Mon Sep 14 2020 andy great <andythe_great@pm.me>
- Add patch to enable debuginfo from Fedora.
  * https://src.fedoraproject.org/rpms/goverlay/tree/master
* Mon Sep 14 2020 andy great <andythe_great@pm.me>
- Initial package release.
